/**
 * LICENSE 
 * Bonita
 * Copyright (C) 2005 Bull S.A.
 * Bull 68 route de versailles  78434 Louveciennes Cedex France
 * Further information: bonita@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */
package org.ow2.proed.chi.test;

import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.jdom.Document;
import org.jdom.Element;
import org.jdom.output.Format;
import org.jdom.output.XMLOutputter;
import org.ow2.proed.graphModel.AtomicActivity;
import org.ow2.proed.graphModel.ProEdProject;
import org.ow2.proed.graphModel.ProcessActivity;
import org.ow2.proed.graphModel.WorkflowProcess;
import org.ow2.proed.graphModel.WorkflowProcesses;
import org.ow2.proed.graphModel.ProcessActivity.ExecutionMode;
import org.ow2.proed.xpdl.XPDLProcessActivity;
import org.ow2.proed.xpdl.XPDLProperty;
import org.ow2.proed.xpdl.XPDLUtil;

/**
 * XPDLAtomicActivityTest.java Created on 20 juin 2005
 * 
 * @author Ducreux Evelyne - Gonthier Manu�la
 * @version $Id: XPDLAtomicActivityTest.java 3505 2008-09-18 13:16:10Z vigneras
 *          $
 *          <p>
 */
public class XPDLAtomicActivityTest extends TestCase {

  private ProEdProject project;

  private AtomicActivity a1;

  private AtomicActivity a2;

  private AtomicActivity a3;

  private AtomicActivity a4;

  @Override
  protected void setUp() {
    this.project = new ProEdProject("Project1", false);
    final WorkflowProcesses workflows = new WorkflowProcesses();
    final WorkflowProcess mainWorkflow = new WorkflowProcess("project1");
    this.project.setMyProcesses(workflows);
    workflows.add(mainWorkflow);
    this.a1 = new AtomicActivity("Activity 1", null, null, null, ExecutionMode.Synchronous, mainWorkflow, null, null);
    this.a2 = new AtomicActivity("Activity 2", "2eme activity", ProcessActivity.MANUAL_MODE, null, ExecutionMode.Synchronous, mainWorkflow, null, null);
    this.a3 = new AtomicActivity("Activity 3", "super", null, null, ExecutionMode.Synchronous, mainWorkflow, null, null);
    this.a4 = new AtomicActivity("Activity 4", "activity 4", ProcessActivity.AUTO_MODE, ProcessActivity.TYPE_AND_JOIN, ExecutionMode.Synchronous, mainWorkflow,
        null, null);
  }

  public void testGenerationXPDL() {
    final Document document = new Document();
    final Format format = Format.getPrettyFormat();
    format.setEncoding(XPDLProperty.XPDL_ENCODING);
    final XMLOutputter sortie = new XMLOutputter(format);
    final Element elt = new Element("Test");
    final XPDLProcessActivity xpdlPA = new XPDLProcessActivity(this.a1);
    Assert.assertNotNull(xpdlPA);

    xpdlPA.toXML(elt);
    document.addContent(elt);

    try {
      System.out.print(XPDLUtil.changeNameSpace(sortie.outputString(document)));

    } catch (final Exception ioe) {
      System.err.println(ioe.getMessage());
    }

  }

  public static Test suite() {
    return new TestSuite(XPDLAtomicActivityTest.class);
  }

  public static void main(final String args[]) {
    junit.textui.TestRunner.run(XPDLAtomicActivityTest.class);
  }
}