/**
 * LICENSE 
 * Bonita
 * Copyright (C) 2005 Bull S.A.
 * Bull 68 route de versailles  78434 Louveciennes Cedex France
 * Further information: bonita@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */
package org.ow2.proed.chi.test.graphModel;

import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.ow2.proed.graphModel.ProEdProject;
import org.ow2.proed.graphModel.ProcessActivity;
import org.ow2.proed.graphModel.RouteActivity;
import org.ow2.proed.graphModel.Subflow;
import org.ow2.proed.graphModel.WorkflowProcess;
import org.ow2.proed.graphModel.WorkflowProcesses;
import org.ow2.proed.graphModel.ProcessActivity.ExecutionMode;

/**
 * RootActivityTest.java Created on 11 juil. 2005
 * 
 * @author Ducreux Evelyne - Gonthier Manu�la
 * @version $Id: RootActivityTest.java 4407 2009-02-18 16:55:11Z vigneras $
 *          <p>
 */
public class RootActivityTest extends TestCase {

  private ProEdProject project;

  private WorkflowProcess mainWorkflow;

  private RouteActivity a1;

  private RouteActivity a2;

  private RouteActivity a3;

  private RouteActivity a4;

  private RouteActivity a5;

  private ProcessActivity processActivity;

  /*
   * @see TestCase#setUp()
   */
  @Override
  protected void setUp() throws Exception {
    this.project = new ProEdProject("Project1", false);
    final WorkflowProcesses workflows = new WorkflowProcesses();
    this.mainWorkflow = new WorkflowProcess("project1");
    this.project.setMyProcesses(workflows);
    workflows.add(this.mainWorkflow);

    this.a1 = new RouteActivity("Activity 1", null, null, null, ExecutionMode.Synchronous, this.mainWorkflow, null);
    Assert.assertNotNull(this.a1);
    this.a2 = new RouteActivity("Activity 2", "2eme activity", ProcessActivity.MANUAL_MODE, null, ExecutionMode.Synchronous, this.mainWorkflow, null);
    Assert.assertNotNull(this.a2);
    this.a3 = new RouteActivity("Activity 3", "super", null, null, ExecutionMode.Synchronous, this.mainWorkflow, null);
    Assert.assertNotNull(this.a3);
    this.a4 = new RouteActivity("Activity 4", "activity 4", ProcessActivity.AUTO_MODE, ProcessActivity.TYPE_AND_JOIN, ExecutionMode.Synchronous, this.mainWorkflow,
        null);
    Assert.assertNotNull(this.a4);
  }

  public void testConstructAtomicActivity() {
    this.processActivity = new Subflow("subflow", "activity to copy", ProcessActivity.TYPE_AND_JOIN, ExecutionMode.Synchronous, this.mainWorkflow, null);
    // test construction of atomic activity with processActivity
    this.a5 = RouteActivity.constructRouteActivity(this.processActivity);
    System.out.println("\nA5:" + this.a5.printtoString());
    System.out.println("\nProcessActivity:" + this.processActivity.printtoString());

  }

  public static Test suite() {
    return new TestSuite(RootActivityTest.class);
  }

}
